@@ -14,7 +14,7 @@ BIFIE.linreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 	if (bifieobj$cdata){
 	    formula_vars <- NULL
 		if (! is.null(formula) ){
-			formula_vars <- base::all.vars( formula )
+			formula_vars <- all.vars( formula )
 							}
 		varnames <- unique( c( dep , pre , group , "one" , formula_vars ) )
 		bifieobj <- BIFIE.BIFIEcdata2BIFIEdata( bifieobj , varnames=varnames )	
@@ -153,4 +153,4 @@ summary.BIFIE.linreg <- function( object , digits=4 , ... ){
 	cat("Statistical Inference for Linear Regression \n\n")	
 	obji <- object$stat
 	print.object.summary( obji , digits=digits )
-			}
\ No newline at end of file
+			}
