@@ -3,30 +3,30 @@
 ###########################################
 # Rcpp version of R's table function
 fasttable <- function( vec  , sort.names=FALSE ){
-    datavec <- base::matrix( vec , ncol=1 )
+    datavec <- matrix( vec , ncol=1 )
     # res <- bifie_fasttable( datavec )	
-	if ( base::storage.mode(vec) == "character" ){
+	if ( storage.mode(vec) == "character" ){
 				characters <- TRUE	
 					} else {
 				characters <- FALSE
 						}
 	if ( ! characters ){
-		res <- base::.Call("bifie_fasttable" , datavec , PACKAGE="BIFIEsurvey" )
+		res <- .Call("bifie_fasttable" , datavec , PACKAGE="BIFIEsurvey" )
 		res1 <- res$tableM[ 1:res$N_unique , , drop=FALSE]
 		tvec <- res1[,2]
 		names(tvec) <- res1[,1]
 				}
 	if ( characters ){ 			
 		# t1 <- bifie_table1_character( vec )
-		t1 <- base::.Call("bifie_table1_character" , vec , PACKAGE="BIFIEsurvey")
+		t1 <- .Call("bifie_table1_character" , vec , PACKAGE="BIFIEsurvey")
 		res <- t1$tableM
 		names(res) <- t1$table_names
 		if ( sort.names ){ 
-			tvec <- res[ base::sort( names(res) ) ]
+			tvec <- res[ sort( names(res) ) ]
 					} else { tvec <- res }
 					}								
-    base::return(tvec)
+    return(tvec)
         }
 ###########################################		
 
-bifietable <- fasttable
\ No newline at end of file
+bifietable <- fasttable
